==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QSplitter.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QSplitter (
  QSplitterValue (..),
  QSplitterConstPtr (..),
  QSplitterPtr (..),
  QSplitterConst,
  QSplitter,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithOrientation,
  newWithOrientationAndParent,
  newWithParent,
  addWidget,
  childrenCollapsible,
  count,
  handleWidth,
  indexOf,
  insertWidget,
  isCollapsible,
  opaqueResize,
  orientation,
  refresh,
  setChildrenCollapsible,
  setCollapsible,
  setHandleWidth,
  setOpaqueResize,
  setOrientation,
  setSizes,
  setStretchFactor,
  sizes,
  widget,
  splitterMovedSignal,
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QSplitter
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP


castConst = toQSplitterConst
cast = toQSplitter
downCastConst = downToQSplitterConst
downCast = downToQSplitter

splitterMovedSignal :: (QSplitterPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.Int -> HoppyP.IO ())
splitterMovedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerIntInt_new fn'
    listenerIntInt_connectListener listener' object' "2splitterMoved(int,int)"
  , QtahSignal.internalName = "QSplitter::splitterMoved (ListenerIntInt)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QSplitter.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QSplitter (
  QSplitterValue (..),
  QSplitterConstPtr (..),
  QSplitterPtr (..),
  QSplitterConst,
  QSplitter,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithOrientation,
  newWithOrientationAndParent,
  newWithParent,
  addWidget,
  childrenCollapsible,
  count,
  emitSplitterMoved,
  handleWidth,
  indexOf,
  insertWidget,
  isCollapsible,
  opaqueResize,
  orientation,
  refresh,
  setChildrenCollapsible,
  setCollapsible,
  setHandleWidth,
  setOpaqueResize,
  setOrientation,
  setSizes,
  setStretchFactor,
  sizes,
  widget,
  splitterMovedSignal,
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QSplitter
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQSplitterConst
cast = toQSplitter
downCastConst = downToQSplitterConst
downCast = downToQSplitter

splitterMovedSignal :: (QSplitterPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.Int -> HoppyP.IO ())
splitterMovedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerIntInt_new object' "2splitterMoved(int,int)" fn'
    valid' <- listenerIntInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QSplitter::splitterMoved (ListenerIntInt)"
  }
